Module block

Module block 

RustRadio Block implementation

Blocks are the main building blocks of rustradio. They each do one thing, and you connect them together with streams to process the data.

Enums

BlockRet
Return type for all blocks.

Traits

Block
Block trait. Must be implemented for all blocks.
BlockEOF
Enable asking if a block is done, and will never return any more data.
BlockName
Provide name of block.