Module data_stream

Module data_stream 

DataStream implementation.

Protocol is documented in DATA_STREAM.md. It’s an experimental serialized version of a stream meant primarily for use on a websocket between native and a WASM UI.

This protocol may be replaced by something more “SDR over network” standard. Though of course for our primary use case it always has to run on top of a websocket.

Structs

BytesReader
DATA_STREAM.md packet reader for caller-provided byte chunks.
Data
Data bytes for a named stream.
DataStreamId
Protocol stream identifier.
RequestData
Request more data for a named stream.
SyncReader
Synchronous DATA_STREAM.md packet reader.
SyncWriter
Synchronous DATA_STREAM.md packet writer.

Enums

Packet
DATA_STREAM.md packet.
PacketRef
Borrowed DATA_STREAM.md packet for writing.

Constants

DEFAULT_MAX_PACKET_LEN
Default maximum payload size accepted by readers.
PROTOCOL_VERSION
Current DATA_STREAM.md protocol version.