FftStream

Struct FftStream 

pub struct FftStream { /* private fields */ }
Takes a stream of data, runs an FFT on it, and outputs it as a stream. The consumer of the stream needs to know what the FFT size is, or it won’t be able to make sense of it.

Implementations

Source

impl FftStream

pub fn new(src: ReadStream<Complex>, size: usize) -> (Self, ReadStream<Complex>)

Create a new FftStream.

pub fn threaded(&mut self, onoff: bool)

Turn on or off Rayon multithreading.

Initial benchmarks seem to indicate that this does not help. Maybe with bigger than default stream buffers for more concurrency.