Module graph

Module graph 

Graphs contain blocks connected by streams, and run them.

Structs

CancellationToken
A handle to be able to stop the Graph. For example when the user presses Ctrl-C.
Graph
A graph is a thing that RustRadio runs, to let blocks “talk to each other” via streams.

Traits

GraphRunner
Abstraction over graph executors.