Module stream

Module stream 

Streams connecting blocks.

Blocks are connected with streams. A block can have zero or more input streams, and write to zero or more output streams.

Structs

NCReadStream
A stream of noncopyable objects (e.g. Vec / PDUs).
NCWriteStream
A stream of noncopyable objects (e.g. Vec / PDUs).
ReadStream
ReadStream is the reading side of a stream.
Tag
Tags associated with a stream.
WriteStream
The write part of a stream.

Enums

TagValue
Enum of tag values.

Traits

StreamReadSide
Trait that helps finding the read side type of a write stream.
StreamWait
Wait on a stream.

Functions

new_nocopy_stream
Create a new stream for data elements that do not implement Copy.
new_stream
Create a new stream for data elements that implements Copy.

Type Aliases

TagPos
Tag position in the current stream.