DataStream implementation.
Protocol is documented in DATA_STREAM.md. It’s an experimental serialized version of a stream meant primarily for use on a websocket between native and a WASM UI.
This protocol may be replaced by something more “SDR over network” standard. Though of course for our primary use case it always has to run on top of a websocket.
Structs
- Bytes
Reader - DATA_STREAM.md packet reader for caller-provided byte chunks.
- Data
- Data bytes for a named stream.
- Data
Stream Id - Protocol stream identifier.
- Request
Data - Request more data for a named stream.
- Sync
Reader - Synchronous DATA_STREAM.md packet reader.
- Sync
Writer - Synchronous DATA_STREAM.md packet writer.
Enums
Constants
- DEFAULT_
MAX_ PACKET_ LEN - Default maximum payload size accepted by readers.
- PROTOCOL_
VERSION - Current DATA_STREAM.md protocol version.