pub struct FftStream { /* private fields */ }Expand description
Takes a stream of data, runs an FFT on it, and outputs it as a stream. The consumer of the stream needs to know what the FFT size is, or it won’t be able to make sense of it.
Implementations
Sourceimpl FftStream
impl FftStream
Sourcepub fn new(src: ReadStream<Complex>, size: usize) -> (Self, ReadStream<Complex>)
pub fn new(src: ReadStream<Complex>, size: usize) -> (Self, ReadStream<Complex>)
Create a new FftStream.