Graphs contain blocks connected by streams, and run them.
Structs
- Cancellation
Token - A handle to be able to stop the Graph. For example when the user presses Ctrl-C.
- Graph
- A graph is a thing that RustRadio runs, to let blocks “talk to each other” via streams.
Traits
- Graph
Runner - Abstraction over graph executors.