Streams connecting blocks.
Blocks are connected with streams. A block can have zero or more input streams, and write to zero or more output streams.
Structs
- NCRead
Stream - A stream of noncopyable objects (e.g. Vec / PDUs).
- NCWrite
Stream - A stream of noncopyable objects (e.g. Vec / PDUs).
- Read
Stream ReadStreamis the reading side of a stream.- Tag
- Tags associated with a stream.
- Write
Stream - The write part of a stream.
Enums
- TagValue
- Enum of tag values.
Traits
- Stream
Read Side - Trait that helps finding the read side type of a write stream.
- Stream
Wait - Wait on a stream.
Functions
- new_
nocopy_ stream - Create a new stream for data elements that do not implement Copy.
- new_
stream - Create a new stream for data elements that implements Copy.
Type Aliases
- TagPos
- Tag position in the current stream.