pub fn new_stream<T>() -> (WriteStream<T>, ReadStream<T>)Expand description
Create a new stream for data elements that implements Copy.
That’s not to say that a bunch of Copy happens, but that it makes sense to create sync blocks that take samples by value.
Basically anything that GNU Radio would not call a message port.